diff --git a/docs/FAQ.md b/docs/FAQ.md index 913591a11..1f442f07a 100644 --- a/docs/FAQ.md +++ b/docs/FAQ.md @@ -400,9 +400,6 @@ netCDF-4.1.3 with 32- and 64-bit versions, Fortran bindings, and OPeNDAP support. The announcement of the availability of that port is [here](https://www.unidata.ucar.edu/mailing_lists/archives/netcdfgroup/2011/msg00363.html). -User Veit Eitner has contributed a port of 4.1.1 to Visual Studio, -including an F90 port to Intel Fortran. Download [source (ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/netcdf-4.1.1-win32-src.zip)](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/netcdf-4.1.1-win32-src.zip) or [binary](https://downloads.unidata.ucar.edu/netcdf-c) versions. This port was done before the code was refactored in 4.1.2. - How can I use netCDF-4 with Windows? {#How-can-I-use-netCDF-4-with-Windows} ----------------- @@ -418,18 +415,7 @@ utilities and just install them on your system. Unlike Unix builds, the Visual Studio build **always** requires HDF5, zlib, and szlib in all cases. All Windows DLL users must also have the -HDF5, zlib, and szlib DLLs. These are now available from the Unidata FTP -site: - -- [zlib DLLs for 32-bit Windows](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/zlib123-vs2005.zip) -- [szlib DLLs for 32-bit Windows](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/szip21-vs6-enc.zip) -- [HDF5 DLLs for 32-bit Windows](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/5-181-win-vs2005.zip) - -Two versions of the netCDF DLLs are available, for different Fortran -compilers: - -- [NetCDF for Intel and Portland Group Fortran compilers.](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/win32_vs_PGI_dll_4.0.1.zip) -- [NetCDF for other Fortran compilers.](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/win32_vs_f2c_dll_4.0.1.zip) +HDF5, zlib, and szlib DLLs. To use netCDF, install the DLLs in /system/win32 and the .h files in a directory known to your compiler, and define the DLL\_NETCDF @@ -470,9 +456,6 @@ of the oddities of Windows can be found here: - [cygwin mailing list explanation of Windows DL requirements.](http://cygwin.com/ml/cygwin/2000-06/msg00688.html) - [-mno-cygwin - Building Mingw executables using Cygwin](http://www.delorie.com/howto/cygwin/mno-cygwin-howto.html) -Once you have the netCDF DLL, you may wish to call it from Visual Basic. -The [netCDF VB wrapper](ftp://ftp.unidata.ucar.edu/pub/netcdf/contrib/win32/netcdf_vb_net_wrapper.zip) will help you do this. - The SDS ([Scientific DataSet](http://research.microsoft.com/en-us/projects/sds/)) library and tools provide .Net developers a way to read, write and share scalars, vectors, and multidimensional grids using CSV, netCDF, and other file formats. It currently uses netCDF version 4.0.1. In addition to .Net libraries, SDS provides a set of utilities and packages: an sds command line utility, a DataSet Viewer application and an add-in for Microsoft Excel 2007 (and later versions). ---------- diff --git a/docs/attribute_conventions.md b/docs/attribute_conventions.md index 5a3df819d..b13ec4d69 100644 --- a/docs/attribute_conventions.md +++ b/docs/attribute_conventions.md @@ -115,7 +115,7 @@ It is strongly recommended that applicable conventions be followed unless there `Conventions` -> If present, 'Conventions' is a global attribute that is a character array for the name of the conventions followed by the dataset. Originally, these conventions were named by a string that was interpreted as a directory name relative to the directory /pub/netcdf/Conventions/ on the host ftp.unidata.ucar.edu. The web page https://www.unidata.ucar.edu/netcdf/conventions.html is now the preferred and authoritative location for registering a URI reference to a set of conventions maintained elsewhere. The FTP site will be preserved for compatibility with existing references, but authors of new conventions should submit a request to support-netcdf@unidata.ucar.edu for listing on the Unidata conventions web page. +> If present, 'Conventions' is a global attribute that is a character array for the name of the conventions followed by the dataset. Originally, these conventions were named by a string that was interpreted as a directory name relative to the directory /pub/netcdf/Conventions/ on the now defunct host ftp.unidata.ucar.edu. The web page https://www.unidata.ucar.edu/netcdf/conventions.html is now the preferred and authoritative location for registering a URI reference to a set of conventions maintained elsewhere. Authors of new conventions should submit a request to support-netcdf@unidata.ucar.edu for listing on the Unidata conventions web page.
diff --git a/docs/known_problems.md b/docs/known_problems.md
index a61474e58..7b6fe288a 100644
--- a/docs/known_problems.md
+++ b/docs/known_problems.md
@@ -207,8 +207,7 @@ Currently the workarounds are to either
- Use netCDF-4.1.2-beta2 or later with HDF5 1.8.6
The HDF5 1.8.5-patch1 release is available from the HDF5 site at
-
- Unidata makes available a separate
- catalog
- to a
- directory
- of freely available, user-contributed software and documentation related to the
- netCDF library. This software may be retrieved by anonymous FTP. We haven't
- necessarily used or tested this software; we make it available "as is".
+ Unidata had an archive of user-contributed software and documentation related to the
+ netCDF library. This software is available by request to support-netcdf@unidata.ucar.edu.
+ We haven't necessarily used or tested this software; we make it available "as is".
The criteria for inclusion in the netcdf/contrib/ directory of user-contributed
diff --git a/nc_perf/run_knmi_bm.sh b/nc_perf/run_knmi_bm.sh
index 712ef177b..36d4ad590 100755
--- a/nc_perf/run_knmi_bm.sh
+++ b/nc_perf/run_knmi_bm.sh
@@ -1,6 +1,6 @@
#!/bin/sh
-# This shell gets some files from the netCDF ftp site for testing,
+# This shell gets some sample data files for testing,
# then runs the tst_knmi benchmarking program.
# Ed Hartnett
@@ -15,7 +15,7 @@ echo "Getting KNMI test files $file_list"
for f1 in $file_list
do
if ! test -f $f1; then
- wget ftp://ftp.unidata.ucar.edu/pub/netcdf/sample_data/$f1.gz
+ wget https://resources.unidata.ucar.edu/sample_data/$f1.gz
gunzip $f1.gz
fi
done
FERRET
@@ -1613,11 +1612,9 @@ or using ECMWF reanalysis on a reduced grid
MexEPS
PMEL has developed a MATLAB interface, MexEPS, which supports
- several netCDF file conventions, including those adopted
- by PMEL. Many styles of time axes are supported and time manipulation routines
- ease the use of the time axis in MATLAB. The MexEPS package supports the following
- data formats:
+ several netCDF file conventions, including those adopted by PMEL. Many styles of
+ time axes are supported and time manipulation routines ease the use of the time axis
+ in MATLAB. The MexEPS package supports the following data formats:
User-Contributed Software
diff --git a/hdf4_test/run_get_hdf4_files.sh b/hdf4_test/run_get_hdf4_files.sh
index c0d0a74ac..faf1206a6 100755
--- a/hdf4_test/run_get_hdf4_files.sh
+++ b/hdf4_test/run_get_hdf4_files.sh
@@ -1,8 +1,8 @@
#!/bin/sh
-# This shell gets some sample HDF4 files from the netCDF ftp site for
-# testing. Then it runs program tst_interops3 on the test file to
-# check that HDF4 reading works.
+# This shell gets some sample HDF4 files for testing.
+# Then it runs program tst_interops3 on the test file
+# to check that HDF4 reading works.
# Ed Hartnett
@@ -12,14 +12,14 @@ if test "x$srcdir" = x ; then srcdir=`pwd`; fi
# Uncomment for quiet wget operation.
#Q=-q
# Get a file from the ftp site; retry several times
getfile() {
- FTPFILE="ftp://ftp.unidata.ucar.edu/pub/netcdf/sample_data/hdf4/$1.gz"
+ DATAFILE="https://resources.unidata.ucar.edu/sample_data/hdf4/$1.gz"
for try in 1 2 3 4 ; do # try 4 times
# signal success/failure
- if wget -c $Q --passive-ftp $FTPFILE || curl -O $FTPFILE ; then
+ if wget -c $Q --passive-ftp $DATAFILE || curl -O $DATAFILE ; then
return 0 # got it
fi
echo "wget failed: try $try"
@@ -12,14 +12,14 @@ if test "x$srcdir" = x ; then srcdir=`pwd`; fi
# Uncomment for quiet wget operation.
#Q=-q
-# Get a file from the ftp site; retry several times
+# Get a file from the resources site; retry several times
getfile() {